def add_numbers(num1, num2):
    results = num1 + num2
    return f'{results}'


def subtract_numbers(num1, num2):
    results = num1 - num2
    return f'{results}'


def multiply_numbers(num1, num2):
    results = num1 * num2
    return f'{results}'


def divide_numbers_float(num1, num2):
    results = num1 / num2
    return f'{results}'


def divide_numbers_floor(num1, num2):
    results = num1 // num2
    return f'{results}'


def power_numbers(num1, num2):
    results = num1 ** num2
    return f'{results}'


def mode_numbers(num1, num2):
    results = num1 % num2
    return f'{results}'



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Intended Audience :: Science/Research',
    'Intended Audience :: Education',
    'Natural Language :: English',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
]

setup(
    name='jecalculator',
    version='0.3',
    description='This is a simple library that performs basic python arithmetic operations.',
    long_description=open('README.md').read() + '\n\n' +
    open('CHANGELOG.txt').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/jamalelkhdadi/je-cal',
    author='JAMAL EL KHDADI',
    author_email='jamalelkhdadi@gmail.com',
    license='MIT',
    classifiers=classifiers,
    keywords='calculator',
    packages=find_packages(),
    install_requires=['']
)
